#!/bin/bash
# mongodb install script.

INST_FILE="mongodb-linux-x86_64-2.2.0"

echo ""
echo "----------------------------------------------------------------"
echo "- Installing ${INST_FILE}... "
echo "----------------------------------------------------------------"

echo "Installation Information"
cat ../extra/mongodb_info.txt
echo "Okay to install ${INST_FILE}? ( y/n ) : "
read answer
if [ "$answer" = "n" ] || [ "$answer" = "N" ]; then
	echo "Aborting"
	exit 2
fi
    
if [ -s ${INST_FILE}.tgz ]; then
  echo "${INST_FILE}.tgz [found]"
else
	echo "Error: ${INST_FILE} not found!!! If you have an other install version, you can change the mongoinst.sh file's INST_FILE variable for your install file version and retry installation."
	echo "You need to download below files."
	echo "  1) mongodb-linux-x86_64-2.2.0.tgz"
	echo "      - Download URL: http://www.mongodb.org/downloads"
	echo "      - File download path : ./mongoinst/mongodb-linux-x86_64-2.2.0.tgz"
 exit 1
fi

tar zxvf ${INST_FILE}.tgz -C /usr/local
ln -s /usr/local/${INST_FILE} /usr/local/mongodb

#create mongodb directory 
mkdir -p /data/mongodb
touch /data/mongodb/mongodb.log

#create basic control scripts

mkdir -p /usr/local/mongodb/bin
mkdir -p /usr/local/mongodb/config

#cd /usr/local/mongodb/bin
cp mongodb-start /usr/local/mongodb/bin
cp mongodb-stop /usr/local/mongodb/bin
chmod +x /usr/local/mongodb/bin/*

#config
cat >/usr/local/mongodb/config/mongodb<<EOF
# Configuration Options for MongoDB
# 
# For More Information, Consider:
# - Configuration Parameters: http://www.mongodb.org/display/DOCS/Command+Line+Parameters
# - File Based Configuration: http://www.mongodb.org/display/DOCS/File+Based+Configuration

dbpath = /data/mongodb
logpath = /data/mongodb/mongodb.log
logappend = true

#bind_ip = 127.0.0.1
port = 27017
fork = true

# auth = true
# noauth = true

noprealloc = true
smallfiles = true
nojournal = true
nohttpinterface = true
EOF

#USing a Basic Init Script
cp mongodb /etc/init.d/mongodb
chmod +x /etc/init.d/mongodb

useradd -M -r --home-dir /usr/local/mongodb mongodb
chown mongodb:mongodb -R /usr/local/${INST_FILE}
chown mongodb:mongodb -R /usr/local/mongodb
chown mongodb:mongodb -R /data/mongodb

echo "Do you want to enable ${INST_FILE} automatic start after system reboot? ( y/n ) : "
read answer
if [ "$answer" = "y" ] || [ "$answer" = "Y" ]; then
	chkconfig --add mongodb
	chkconfig mongodb on
fi

/etc/init.d/mongodb start
#/etc/init.d/mongodb stop

sleep 5

echo " "
echo "----------------------------------------------------------------"
echo "- ${INST_FILE} installation is completed. "
echo "----------------------------------------------------------------"

exit 0
